@@ -62,6 +62,8 @@ MassPeakShaperConfigWidget::MassPeakShaperConfigWidget(
   QWidget *parent_p, libmass::MassPeakShaperConfig &config)
   : QWidget(parent_p), m_config(config)
 {
+  qDebug() << "Creating MassPeakShaperConfigWidget";
+  
   if(!parent_p)
     qFatal("Programming error. Program aborted.");
 
@@ -71,6 +73,9 @@ MassPeakShaperConfigWidget::MassPeakShaperConfigWidget(
 
 MassPeakShaperConfigWidget::~MassPeakShaperConfigWidget()
 {
+  // The timer should not try to access a deleted widget!
+  qDebug() << "Stopping the timer.";
+  m_msgTimer.stop();
 }
 
 
@@ -166,6 +171,13 @@ MassPeakShaperConfigWidget::setupWidget()
 
   // Get the number of points used to craft the peak curve.
   m_config.setPointCount(m_ui.pointCountSpinBox->value());
+  
+  // Set the message timer to be singleShot. This time is used to erase the text shown in the message line edit widget after 3 seconds.
+  m_msgTimer.setInterval(3000);
+  m_msgTimer.setSingleShot(true);
+  connect(&m_msgTimer,
+          &QTimer::timeout,
+          [this] (){ m_ui.messageLineEdit->setText("");});
 
   connect(m_ui.referenceMassLineEdit,
           &QLineEdit::textEdited,
@@ -557,7 +569,9 @@ void
 MassPeakShaperConfigWidget::message(const QString &message, int timeout)
 {
   m_ui.messageLineEdit->setText(message);
-  QTimer::singleShot(timeout, [this]() { m_ui.messageLineEdit->setText(""); });
+  m_msgTimer.stop();
+  m_msgTimer.setInterval(timeout);
+  m_msgTimer.start();
 }
 
 
