@@ -387,7 +387,7 @@ BasePlotCompositeWidget::computePlotSize(std::pair<int, int> requested,
   // qDebug() << "Saving PNG file with final dimensions:"
   //<< final_width << final_height;
 
-  return std::pair<int,int>(final_width, final_height);
+  return std::pair<int, int>(final_width, final_height);
 }
 
 
@@ -462,7 +462,7 @@ BasePlotCompositeWidget::savePlotToPngFile(
     std::pair<int, int>(width, height),
     std::pair<int, int>(plot_widget_size.width(), plot_widget_size.height()));
 
-   //qDebug() << "Saving PNG file with final dimensions:"
+  // qDebug() << "Saving PNG file with final dimensions:"
   //<< plot_dimensions.first << plot_dimensions.second;
 
   return mp_plotWidget->savePng(
@@ -482,7 +482,7 @@ BasePlotCompositeWidget::savePlotToJpgFile(
     std::pair<int, int>(width, height),
     std::pair<int, int>(plot_widget_size.width(), plot_widget_size.height()));
 
-   //qDebug() << "Saving JPG file with final dimensions:"
+  // qDebug() << "Saving JPG file with final dimensions:"
   //<< plot_dimensions.first << plot_dimensions.second;
 
   return mp_plotWidget->saveJpg(
@@ -950,7 +950,7 @@ BasePlotCompositeWidget::showMsFragmentationSpecDlg()
   // returned (true boolean below). Only of interest are step with the
   // destination matching MZ.
 
-  std::vector<const ProcessingStep *> processing_steps =
+  std::vector<ProcessingStepCstSPtr> processing_steps =
     processing_flow.stepsMatchingDestType(ProcessingType("MZ"), true);
 
   // qDebug() << "The number of processing specs that match processing
@@ -976,8 +976,8 @@ BasePlotCompositeWidget::showMsFragmentationSpecDlg()
       // There was/were indeed step instances with a valid ms
       // fragmentation spec. Arbitrarily select the last one.
 
-      const ProcessingStep *processing_step_p = processing_steps.back();
-      ms_fragmentation_spec = processing_step_p->getMsFragmentationSpec();
+      ProcessingStepCstSPtr processing_step_csp = processing_steps.back();
+      ms_fragmentation_spec = processing_step_csp->getMsFragmentationSpec();
     }
 
   // We can finally use it to  configure the dialog window.
