@@ -215,7 +215,7 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::integrationRequested(
 
   context.m_selectionPolygon.rangeX(x_range_start, x_range_end);
 
-  //qDebug() << "X axis range:" << x_range_start << "-" << x_range_end;
+  // qDebug() << "X axis range:" << x_range_start << "-" << x_range_end;
 
   if(x_range_start < 0 && x_range_end < 0)
     return;
@@ -225,7 +225,7 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::integrationRequested(
 
   context.m_selectionPolygon.rangeY(y_range_start, y_range_end);
 
-  //qDebug() << "Y axis range:" << y_range_start << "-" << y_range_end;
+  // qDebug() << "Y axis range:" << y_range_start << "-" << y_range_end;
 
   if(y_range_start < 0 && y_range_end < 0)
     return;
@@ -266,17 +266,17 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::integrationRequested(
   ProcessingFlow local_processing_flow =
     getProcessingFlowForPlottable(plottable_p);
 
-  //qDebug().noquote() << "Processing flow for graph:"
-                     //<< local_processing_flow.toString();
+  // qDebug().noquote() << "Processing flow for graph:"
+  //<< local_processing_flow.toString();
 
   MsRunDataSetCstSPtr ms_run_data_set_csp =
     getMsRunDataSetCstSPtrForPlottable(plottable_p);
 
-  //qDebug() << ms_run_data_set_csp->getMsRunDataSetStats().toString();
+  // qDebug() << ms_run_data_set_csp->getMsRunDataSetStats().toString();
 
   // Create a processing step to document the specifics of this new integration.
 
-  ProcessingStep *processing_step_p = new ProcessingStep();
+  ProcessingStepSPtr processing_step_sp = std::make_shared<ProcessingStep>();
 
   // If the user had set ms fragmentation specifications, all these are listed
   // in the various ProcessingSpec instances, so we do not loose any. However,
@@ -295,7 +295,7 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::integrationRequested(
       // flow " "is valid, using it:"
       //<< ms_fragmentation_spec.toString();
 
-      processing_step_p->setMsFragmentationSpec(ms_fragmentation_spec);
+      processing_step_sp->setMsFragmentationSpec(ms_fragmentation_spec);
     }
   else
     {
@@ -315,13 +315,13 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::integrationRequested(
       ->yAxisDataKind();
 
   if(x_axis_data_kind == pappso::DataKind::dt)
-  { 
-    qDebug() << "X axis: dt";
-  }
+    {
+      qDebug() << "X axis: dt";
+    }
   else if(x_axis_data_kind == pappso::DataKind::mz)
-  { 
-    qDebug() << "X axis: mz";
-  }
+    {
+      qDebug() << "X axis: mz";
+    }
 
   if(x_axis_data_kind == pappso::DataKind::dt &&
      y_axis_data_kind != pappso::DataKind::mz)
@@ -353,48 +353,50 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::integrationRequested(
   // else
   // No need to tranpose, we deal with data in the right x:MZ y:DT.
 
-  //qDebug() << "The selection polygon:" << local_selection_polygon.toString();
+  // qDebug() << "The selection polygon:" << local_selection_polygon.toString();
 
   // Now we know we have the right selection polygon for x:MZ and y:DT.
 
-  processing_step_p->setDataKind(pappso::Axis::x, pappso::DataKind::dt);
-  processing_step_p->setDataKind(pappso::Axis::y, pappso::DataKind::mz);
+  processing_step_sp->setDataKind(pappso::Axis::x, pappso::DataKind::dt);
+  processing_step_sp->setDataKind(pappso::Axis::y, pappso::DataKind::mz);
 
 
   // And now actually set the selection polygon to the step.
 
-  processing_step_p->setSelectionPolygon(local_selection_polygon);
+  processing_step_sp->setSelectionPolygon(local_selection_polygon);
 
   // qDebug() << "Selection polygon as set to the step:"
   //<< processing_step_p->getSelectionPolygon().toString();
 
   // We must say what is the data source processing type.
-  processing_step_p->setSrcProcessingType(pappso::Axis::x, "DT");
-  processing_step_p->setSrcProcessingType(pappso::Axis::y, "MZ");
+  processing_step_sp->setSrcProcessingType(pappso::Axis::x, "DT");
+  processing_step_sp->setSrcProcessingType(pappso::Axis::y, "MZ");
 
   // Now we need to document not the source but the destination. What kind of
   // integration are we about to perform?
 
   if(m_ui.integrateToRtPushButton->isChecked())
     {
-      //qDebug() << "Integrating to XIC chromatogram.";
+      // qDebug() << "Integrating to XIC chromatogram.";
 
       // We need to set two specs to the step.
 
-      processing_step_p->setDestProcessingType("RT");
+      processing_step_sp->setDestProcessingType("RT");
 
-      local_processing_flow.push_back(processing_step_p);
+      // Should perform automatically the conversion from non-const to const.
+      local_processing_flow.push_back(processing_step_sp);
 
       static_cast<BaseColorMapPlotWnd *>(mp_parentWnd)
         ->integrateToRt(plottable_p, local_processing_flow);
     }
   else if(m_ui.integrateToDtRtPushButton->isChecked())
     {
-      //qDebug() << "Integrating to dt / rt color map.";
+      // qDebug() << "Integrating to dt / rt color map.";
 
-      processing_step_p->setDestProcessingType("DT_RT");
+      processing_step_sp->setDestProcessingType("DT_RT");
 
-      local_processing_flow.push_back(processing_step_p);
+      // Should perform automatically the conversion from non-const to const.
+      local_processing_flow.push_back(processing_step_sp);
 
       static_cast<BaseColorMapPlotWnd *>(mp_parentWnd)
         ->integrateToDtRt(plottable_p, local_processing_flow);
@@ -406,21 +408,21 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::integrationRequested(
     {
       if(m_ui.integrateToMzPushButton->isChecked())
         {
-          //qDebug() << "Integrating to mass spectrum.";
+          // qDebug() << "Integrating to mass spectrum.";
 
-          processing_step_p->setDestProcessingType("MZ");
+          processing_step_sp->setDestProcessingType("MZ");
         }
       else if(m_ui.integrateToMzRtPushButton->isChecked())
         {
-          //qDebug() << "Integrating to rt / m/z color map.";
+          // qDebug() << "Integrating to rt / m/z color map.";
 
-          processing_step_p->setDestProcessingType("MZ_RT");
+          processing_step_sp->setDestProcessingType("MZ_RT");
         }
       else if(m_ui.integrateToDtMzPushButton->isChecked())
         {
-          //qDebug() << "Integrating to dt / m/z color map.";
+          // qDebug() << "Integrating to dt / m/z color map.";
 
-          processing_step_p->setDestProcessingType("DT_MZ");
+          processing_step_sp->setDestProcessingType("DT_MZ");
         }
 
       // At this point we need to define how the mass data integrator will
@@ -434,18 +436,18 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::integrationRequested(
       pappso::MzIntegrationParams mz_integration_params =
         local_processing_flow.getDefaultMzIntegrationParams();
 
-      //qDebug()
-        //<< "The graph's processing flow has default mz integration params:"
-        //<< mz_integration_params.toString();
+      // qDebug()
+      //<< "The graph's processing flow has default mz integration params:"
+      //<< mz_integration_params.toString();
 
       // If it is not valid, then try mz integration params from the various
       // steps of the flow. Preferentially the most recent ones.
       if(!mz_integration_params.isValid())
         {
-          //qDebug()
-            //<< "The processing flow's default mz integ params are not "
-               //"valid. Trying to get the most recent mz integ params "
-               //"from the processing flow. If valid, we may tune them later.";
+          // qDebug()
+          //<< "The processing flow's default mz integ params are not "
+          //"valid. Trying to get the most recent mz integ params "
+          //"from the processing flow. If valid, we may tune them later.";
 
           mz_integration_params =
             *(local_processing_flow.mostRecentMzIntegrationParams());
@@ -456,17 +458,17 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::integrationRequested(
       // while it was loaded from file.
       if(!mz_integration_params.isValid())
         {
-          //qDebug() << "The most recent mz integ param are not valid. We use "
-                      //"the getMsRunDataSetStats to craft new ones that we may "
-                      //"tune later.";
+          // qDebug() << "The most recent mz integ param are not valid. We use "
+          //"the getMsRunDataSetStats to craft new ones that we may "
+          //"tune later.";
 
           mz_integration_params =
             ms_run_data_set_csp->craftInitialMzIntegrationParams();
         }
       else
         {
-          //qDebug() << "The most recent mz integ params are valid. Use them, "
-                      //"with potential tuning.";
+          // qDebug() << "The most recent mz integ params are valid. Use them, "
+          //"with potential tuning.";
         }
 
       if(!mz_integration_params.isValid())
@@ -500,8 +502,8 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::integrationRequested(
       mz_integration_params.setSmallestMz(mz_range_lower);
       mz_integration_params.setGreatestMz(mz_range_upper);
 
-      //qDebug() << "After tuning the mz range, mz integration params:"
-               //<< mz_integration_params.toString();
+      // qDebug() << "After tuning the mz range, mz integration params:"
+      //<< mz_integration_params.toString();
 
 
 #if 0
@@ -524,12 +526,14 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::integrationRequested(
 
       // We finally have mz integ params that we can set to the processing
       // step that we are creating to document this current integration.
-      processing_step_p->setMzIntegrationParams(mz_integration_params);
+      processing_step_sp->setMzIntegrationParams(mz_integration_params);
 
       // And now add the new processing step to the local copy of the
       // processing flow, so that we document on top of all the previous
       // steps, also this last one.
-      local_processing_flow.push_back(processing_step_p);
+
+      // Should perform automatically the conversion from non-const to const.
+      local_processing_flow.push_back(processing_step_sp);
 
       // qDebug().noquote() << "Pushed back new processing step:"
       //<< processing_step_p->toString();
@@ -555,22 +559,24 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::integrationRequested(
     }
   else if(m_ui.integrateToDtPushButton->isChecked())
     {
-      //qDebug() << "Integrating to drift spectrum.";
+      // qDebug() << "Integrating to drift spectrum.";
 
-      processing_step_p->setDestProcessingType("DT");
+      processing_step_sp->setDestProcessingType("DT");
 
-      local_processing_flow.push_back(processing_step_p);
+      // Should perform automatically the conversion from non-const to const.
+      local_processing_flow.push_back(processing_step_sp);
 
       static_cast<BaseColorMapPlotWnd *>(mp_parentWnd)
         ->integrateToDt(plottable_p, local_processing_flow);
     }
   else if(m_ui.integrateToIntPushButton->isChecked())
     {
-      //qDebug() << "Integrating to TIC intensity.";
+      // qDebug() << "Integrating to TIC intensity.";
 
-      processing_step_p->setDestProcessingType("INT");
+      processing_step_sp->setDestProcessingType("INT");
 
-      local_processing_flow.push_back(processing_step_p);
+      // Should perform automatically the conversion from non-const to const.
+      local_processing_flow.push_back(processing_step_sp);
 
       static_cast<BasePlotWnd *>(mp_parentWnd)
         ->integrateToTicIntensity(plottable_p, nullptr, local_processing_flow);
