@@ -568,7 +568,7 @@ MassSpecTracePlotCompositeWidget::gaussianFitOnVisibleMaxima()
   // QClipboard *clipboard = QApplication::clipboard();
   // clipboard->setText(read_trace.toString());
 
-#endif 
+#endif
 
 #if 0
 
@@ -1029,7 +1029,7 @@ MassSpecTracePlotCompositeWidget::integrationRequested(
   // Create a processing step to document the specifics of this new
   // integration.
 
-  ProcessingStep *processing_step_p = new ProcessingStep();
+  ProcessingStepSPtr processing_step_sp = std::make_shared<ProcessingStep>();
 
   MsFragmentationSpec ms_fragmentation_spec =
     local_processing_flow.getDefaultMsFragmentationSpec();
@@ -1041,7 +1041,7 @@ MassSpecTracePlotCompositeWidget::integrationRequested(
       // processing flow " "is valid, using it : "
       //<< ms_fragmentation_spec.toString();
 
-      processing_step_p->setMsFragmentationSpec(ms_fragmentation_spec);
+      processing_step_sp->setMsFragmentationSpec(ms_fragmentation_spec);
     }
   else
     {
@@ -1054,23 +1054,24 @@ MassSpecTracePlotCompositeWidget::integrationRequested(
   // Now make sure we document the selection polygon.
   // Now define the graph range for the integration operation.
 
-  processing_step_p->setSelectionPolygon(local_context.m_selectionPolygon);
+  processing_step_sp->setSelectionPolygon(local_context.m_selectionPolygon);
 
   // We must say what is the data source processing type.
-  processing_step_p->setSrcProcessingType(pappso::Axis::x, "MZ");
+  processing_step_sp->setSrcProcessingType(pappso::Axis::x, "MZ");
 
   // It is essential that we document the relation between the axes and
   // the corresponding data type.
-  processing_step_p->setDataKind(pappso::Axis::x, pappso::DataKind::mz);
-  processing_step_p->setDataKind(pappso::Axis::y, pappso::DataKind::unset);
+  processing_step_sp->setDataKind(pappso::Axis::x, pappso::DataKind::mz);
+  processing_step_sp->setDataKind(pappso::Axis::y, pappso::DataKind::unset);
 
   if(m_ui.integrateToRtPushButton->isChecked())
     {
       // qDebug() << "Integrating to XIC chromatogram.";
 
-      processing_step_p->setDestProcessingType("RT");
+      processing_step_sp->setDestProcessingType("RT");
 
-      local_processing_flow.push_back(processing_step_p);
+      // Should perform automatically the conversion from non-const to const.
+      local_processing_flow.push_back(processing_step_sp);
 
       static_cast<MassSpecTracePlotWnd *>(mp_parentWnd)
         ->integrateToRt(plottable_p, local_processing_flow);
@@ -1082,17 +1083,17 @@ MassSpecTracePlotCompositeWidget::integrationRequested(
       if(m_ui.integrateToMzPushButton->isChecked())
         {
           // qDebug() << "Integrating to mass spectrum.";
-          processing_step_p->setDestProcessingType("MZ");
+          processing_step_sp->setDestProcessingType("MZ");
         }
       else if(m_ui.integrateToMzRtPushButton->isChecked())
         {
           // qDebug() << "Integrating to rt|m/z color map.";
-          processing_step_p->setDestProcessingType("MZ_RT");
+          processing_step_sp->setDestProcessingType("MZ_RT");
         }
       else if(m_ui.integrateToDtMzPushButton->isChecked())
         {
           // qDebug() << "Integrating to dt|m/z color map.";
-          processing_step_p->setDestProcessingType("DT_MZ");
+          processing_step_sp->setDestProcessingType("DT_MZ");
         }
 
       // At this point we need to define how the mass data integrator will
@@ -1149,12 +1150,14 @@ MassSpecTracePlotCompositeWidget::integrationRequested(
 
       // We finally have mz integ params that we can set to the processing
       // step that we are creating to document this current integration.
-      processing_step_p->setMzIntegrationParams(mz_integration_params);
+      processing_step_sp->setMzIntegrationParams(mz_integration_params);
 
       // And nwo add the new processing step to the local copy of the
       // processing flow, so that we document on top of all the previous
       // steps, also this last one.
-      local_processing_flow.push_back(processing_step_p);
+
+      // Should perform automatically the conversion from non-const to const.
+      local_processing_flow.push_back(processing_step_sp);
 
       // qDebug().noquote() << "Pushed back new processing step:"
       //<< processing_step_p->toString();
@@ -1182,9 +1185,10 @@ MassSpecTracePlotCompositeWidget::integrationRequested(
     {
       // qDebug() << "Integrating to drift spectrum.";
 
-      processing_step_p->setDestProcessingType("DT");
+      processing_step_sp->setDestProcessingType("DT");
 
-      local_processing_flow.push_back(processing_step_p);
+      // Should perform automatically the conversion from non-const to const.
+      local_processing_flow.push_back(processing_step_sp);
 
       static_cast<MassSpecTracePlotWnd *>(mp_parentWnd)
         ->integrateToDt(plottable_p, local_processing_flow);
@@ -1194,9 +1198,10 @@ MassSpecTracePlotCompositeWidget::integrationRequested(
       // qDebug() << "Integrating to TIC|XIC chromatogram / drift spectrum
       // colormap.";
 
-      processing_step_p->setDestProcessingType("DT_RT");
+      processing_step_sp->setDestProcessingType("DT_RT");
 
-      local_processing_flow.push_back(processing_step_p);
+      // Should perform automatically the conversion from non-const to const.
+      local_processing_flow.push_back(processing_step_sp);
 
       static_cast<MassSpecTracePlotWnd *>(mp_parentWnd)
         ->integrateToDtRt(plottable_p, local_processing_flow);
@@ -1205,9 +1210,10 @@ MassSpecTracePlotCompositeWidget::integrationRequested(
     {
       // qDebug() << "Integrating to TIC intensity.";
 
-      processing_step_p->setDestProcessingType("INT");
+      processing_step_sp->setDestProcessingType("INT");
 
-      local_processing_flow.push_back(processing_step_p);
+      // Should perform automatically the conversion from non-const to const.
+      local_processing_flow.push_back(processing_step_sp);
 
       static_cast<BasePlotWnd *>(mp_parentWnd)
         ->integrateToTicIntensity(plottable_p, nullptr, local_processing_flow);
@@ -1371,7 +1377,7 @@ MassSpecTracePlotCompositeWidget::addTrace(
                   QVector<double> value_vector;
 
                   // Apparently, as of 20210928, that bug is fixed.
-                  //#pragma GCC warning "Filippo Rusconi: Please check if
+                  // #pragma GCC warning "Filippo Rusconi: Please check if
                   // the
                   // bug was fixed in Qt"
 
@@ -1507,7 +1513,7 @@ MassSpecTracePlotCompositeWidget::addTrace(
                   QVector<double> value_vector;
 
                   // Apparently, as of 20210928, that bug is fixed.
-                  //#pragma GCC warning "Filippo Rusconi: Please check if
+                  // #pragma GCC warning "Filippo Rusconi: Please check if
                   // the
                   // bug was fixed in Qt"
 
