@@ -46,6 +46,7 @@
 #include "BaseTracePlotWnd.hpp"
 #include "MassSpecTracePlotCompositeWidget.hpp"
 #include "../nongui/QualifiedMassSpectrumVectorMassDataIntegratorToMz.hpp"
+#include <pappsomspp/trace/trace.h>
 
 namespace msxps
 {
@@ -84,20 +85,27 @@ class MassSpecTracePlotWnd : public BaseTracePlotWnd
                      const ProcessingFlow &processing_flow);
 
   void integrateToMzRt(QCPAbstractPlottable *plottable_p,
-                     const ProcessingFlow &processing_flow);
+                       const ProcessingFlow &processing_flow);
 
   void integrateToDt(QCPAbstractPlottable *plottable_p,
                      const ProcessingFlow &processing_flow);
 
   void integrateToDtMz(QCPAbstractPlottable *plottable_p,
-                     const ProcessingFlow &processing_flow);
+                       const ProcessingFlow &processing_flow);
 
   void integrateToDtRt(QCPAbstractPlottable *plottable_p,
-                     const ProcessingFlow &processing_flow);
+                       const ProcessingFlow &processing_flow);
 
   void setMinimalChargeFractionalPartPinnedDownWidgets(double value);
   void setChargeStateEnvelopePeakSpanPinnedDownWidgets(std::size_t value);
 
+  // We can receive a mass spectrum either in the form of a trace or in the form
+  // of a CBOR encoded trace with other info.
+  void handleReceivedData(const QByteArray &byte_array);
+  void handleReceivedData(const QString &title,
+                          const QByteArray &color_byte_array,
+                          pappso::TraceCstSPtr trace_csp);
+
   public slots:
 
   void finishedIntegratingToMz(
@@ -111,15 +119,14 @@ class MassSpecTracePlotWnd : public BaseTracePlotWnd
     QualifiedMassSpectrumVectorMassDataIntegratorToMz *mass_data_integrator_p);
 
   protected:
-
   void extendMainMenu();
 
   double m_minimalFractionalPart = 0.99;
-  std::size_t m_massPeakSpan = 1;
+  std::size_t m_massPeakSpan     = 1;
 
   QAction *mp_setMinimalChargeFractionalPartAction = nullptr;
-  QAction *mp_setMassPeakSpanAction = nullptr;
-  QMenu *mp_deconvolutionsMenu = nullptr;
+  QAction *mp_setMassPeakSpanAction                = nullptr;
+  QMenu *mp_deconvolutionsMenu                     = nullptr;
 };
 
 
