@@ -74,10 +74,12 @@ class MsRunReadTask : public QObject
   public slots:
   void readMsRunData(MsRunReadTask *ms_run_read_task_p,
                      pappso::MsRunReaderSPtr ms_run_reader_sp,
+                     const pappso::MsRunReadConfig &ms_run_read_config,
                      MassSpecDataFileLoaderSPtr loader_sp);
 
   signals:
-  void finishedReadingMsRunDataSignal(MsRunDataSetSPtr ms_run_data_set_sp);
+  void finishedReadingMsRunDataSignal(MsRunDataSetSPtr ms_run_data_set_sp,
+                                      double seconds);
 
   private:
   ProgramWindow *mp_programWindow;
