@@ -663,7 +663,8 @@ OpenMsRunDataSetsDlg::allMsRunDataSets() const
   std::vector<MsRunDataSetCstSPtr> vector_of_ms_run_data_set_csp;
 
   QList<QListWidgetItem *> item_list =
-    m_ui.openMsRunDataSetsListWidget->findItems(".*", Qt::MatchRegularExpression);
+    m_ui.openMsRunDataSetsListWidget->findItems(".*",
+                                                Qt::MatchRegularExpression);
 
   for(int iter = 0; iter < item_list.size(); ++iter)
     {
