@@ -37,12 +37,11 @@
 #include <iostream>
 #include <cstdio>
 #include <iomanip>
-#include <pappsomspp/msfile/msfileaccessor.h>
-#include <pappsomspp/trace/trace.h>
-#include <pappsomspp/types.h>
 #include <thread>
 #include <ctime>
 
+/////////////////////// OpenMP include
+#include <omp.h>
 
 /////////////////////// Qt includes
 #include <QDebug>
@@ -60,15 +59,16 @@
 #include <QThread>
 #include <QDateTime>
 
-
 /////////////////////// pappsomspp includes
+#include <pappsomspp/msfile/msfileaccessor.h>
+#include <pappsomspp/trace/trace.h>
+#include <pappsomspp/types.h>
 #include <pappsomspp/utils.h>
 #include <pappsomspp/processing/combiners/tracepluscombiner.h>
 #include <pappsomspp/processing/combiners/mzintegrationparams.h>
-
+#include <pappsomspp/widget/plotwidget/ticxicchromtraceplotwidget.h>
 
 /////////////////////// Local includes
-
 #include <libmass/PolChemDef.hpp>
 #include <libmass/PolChemDefEntity.hpp>
 #include <libmass/PolChemDefSpec.hpp>
@@ -83,6 +83,7 @@
 #include "../nongui/MassDataIntegratorTask.hpp"
 #include "../nongui/MsRunDataSet.hpp"
 #include "TicXicChromMassSpecColorMapWnd.hpp"
+#include "TicChromPreviewerMassDataLoadDlg.hpp"
 
 
 namespace msxps
@@ -99,6 +100,15 @@ ProgramWindow::ProgramWindow(QWidget *parent, const QString &module_name)
   m_lastUsedDirectory = QDir::home().absolutePath();
 
   setupWindow();
+
+  qDebug() << "There are devices:" << omp_get_num_devices();
+
+#pragma omp target teams num_teams(2)
+  {
+
+
+    qDebug() << "Number of teams:" << omp_get_num_teams();
+  }
 }
 
 
@@ -177,7 +187,7 @@ ProgramWindow::openMassSpectrometryFileDlg(const QString &dir_name,
       if(!res)
         QMessageBox::warning(this,
                              "Mass spectrometry file loading failed",
-                             "The file " + cur_file_name + "failed to load.");
+                             "The file " + cur_file_name + " failed to load.");
     }
 
   return true;
@@ -189,9 +199,9 @@ ProgramWindow::openMassSpectrometryFile(const QString &file_name,
                                         bool full_in_memory,
                                         const QString &sample_name)
 {
-  // qDebug() << "Opening mass spectrometry file:" << file_name
-  //<< "with sample name:" << sample_name
-  //<< "from thread:" << QThread::currentThread();
+  qDebug() << "Opening mass spectrometry file:" << file_name
+           << "with sample name:" << sample_name
+           << "from thread:" << QThread::currentThread();
 
   if(file_name.isEmpty() || !QFileInfo::exists(file_name))
     {
@@ -209,20 +219,13 @@ ProgramWindow::openMassSpectrometryFile(const QString &file_name,
   // used to request a MS run reader appropriate for the MS data file format.
   // Beccause there might be more than one ms run in a single mzML file, we need
   // to have a common prefix for all those ms run ids.
+
   pappso::MsFileAccessor ms_file_accessor(file_name, m_msRunIdPrefix);
 
   // qDebug() << "Could get MsFileAccessor.";
 
-  // Note that if the data type is from Bruker:timsTOF, then we want a specific
-  // ms run reader to start with.
-  // if(ms_file_accessor.getFileFormat() == pappso::MzFormat::brukerTims)
-
-  // Preventively set the preferred ms file reader type in case the reader is
-  // Bruker-tims. This setting  will be accounted for when calling
-  // MsFileAccessor::getMsRunIds() later on.
-
-  ms_file_accessor.setPreferedFileReaderType(
-    pappso::MzFormat::brukerTims, pappso::FileReaderType::tims_frames);
+  // It is only when we ask for MS run ids that the file accessor actually
+  // detects the format of the file. So start with this step.
 
   std::vector<pappso::MsRunIdCstSPtr> ms_run_ids =
     ms_file_accessor.getMsRunIds();
@@ -260,19 +263,357 @@ ProgramWindow::openMassSpectrometryFile(const QString &file_name,
         return false;
     }
 
-  // qDebug() << "The file format was detected as:"
-  //<< pappso::Utils::mzFormatAsString(ms_file_accessor.getFileFormat());
+  // Note that if the data type is from Bruker:timsTOF, then we want a specific
+  // ms run reader to start with.
+
+  // qDebug() << "The MS data file format:" <<
+  // (int)pappso::MzFormat::brukerTims; qDebug() << "And as string:"
+  //          <<
+  //          pappso::Utils::mzFormatAsString(ms_file_accessor.getFileFormat());
+
+  qDebug() << "The file format was detected as:"
+           << pappso::Utils::mzFormatAsString(ms_file_accessor.getFileFormat());
+
+
+  // Allocate a ms run reader config instance for filling its fields below.
+  pappso::MsRunReadConfig ms_run_read_config;
 
   if(ms_file_accessor.getFileFormat() == pappso::MzFormat::brukerTims)
     {
-      QMessageBox msg_box;
-      msg_box.setText(
-        "The Bruker timsTOF data import is experimental.\nAll the mobility "
-        "scans are combined into one single mass spectrum.");
-      msg_box.exec();
+      // At this point, we should try to get some data from the data file so as
+      // to fill the form in the dialog for the user to select data file loading
+      // criteria, like RT range, IM range, m/z binning.
+
+      ms_file_accessor.setPreferedFileReaderType(
+        pappso::MzFormat::brukerTims, pappso::FileReaderType::tims_frames);
+
+      // Get the first run id of the vector.
+      pappso::MsRunIdCstSPtr ms_run_id_csp = ms_run_ids.at(run_index);
+
+      // From the file accessor get a shared pointer to the MS run reader for
+      // the ms run id of interest.
+      pappso::MsRunReaderSPtr ms_run_reader_sp =
+        ms_file_accessor.msRunReaderSp(ms_run_id_csp);
+
+      // We'll pass this object to the dialog below with
+      // data to be set into the dialog's widgets but also
+      // with fields to be set by the dialog.
+      MsRunDataPreviewInfo ms_run_data_preview_info;
+
+      pappso::MsRunReadConfig config;
+      config.setNeedPeakList(false);
+
+      // Question for Olivier: how could we get in one step the number of MS1
+      // and MS2 frames?
+
+      config.setMsLevels({1});
+
+      pappso::MsRunReaderQualifiedSpectrumList spectrum_list_reader;
+      ms_run_reader_sp->readSpectrumCollection2(config, spectrum_list_reader);
+
+      // How many frames are there as MS1 spectra (not MS/MS)
+      ms_run_data_preview_info.ms1SpectraCount =
+        spectrum_list_reader.getQualifiedMassSpectrumList().size();
+
+      QString data_exploration_results =
+        QString("The number of spectra for MS level 1 is %1\n")
+          .arg(ms_run_data_preview_info.ms1SpectraCount);
+
+      double first_spectrum_rt =
+        spectrum_list_reader.getQualifiedMassSpectrumList()
+          .at(0)
+          .getRtInMinutes();
+
+      ms_run_data_preview_info.retentionTimeBeginInSeconds =
+        first_spectrum_rt * 60;
+
+      double last_spectrum_rt =
+        spectrum_list_reader.getQualifiedMassSpectrumList()
+          .at(ms_run_data_preview_info.ms1SpectraCount - 1)
+          .getRtInMinutes();
+
+      ms_run_data_preview_info.retentionTimeEndInSeconds =
+        last_spectrum_rt * 60;
+
+      double tic_chrom_duration_minutes = last_spectrum_rt - last_spectrum_rt;
+      double half_tic_chrom_duration_minutes = tic_chrom_duration_minutes / 2;
+
+      data_exploration_results += QString(
+                                    "The acquisition was performed over the RT "
+                                    "range [%1-%2] for a duration of %3 min.\n")
+                                    .arg(first_spectrum_rt)
+                                    .arg(last_spectrum_rt)
+                                    .arg(tic_chrom_duration_minutes);
+
+      // At this point look in detail at the m/z dimension of the spectrum at
+      // the middle of the acquisition
+      std::size_t middle_acquisition_spectrum_index =
+        ms_run_data_preview_info.ms1SpectraCount / 2;
+
+      pappso::QualifiedMassSpectrum qualified_mass_spectrum =
+        spectrum_list_reader.getQualifiedMassSpectrumList().at(
+          middle_acquisition_spectrum_index);
+
+      half_tic_chrom_duration_minutes =
+        qualified_mass_spectrum.getRtInMinutes();
+
+      data_exploration_results +=
+        QString(
+          "The retention time of the spectrum at mid-acquisition is (min) %1\n")
+          .arg(half_tic_chrom_duration_minutes);
+
+      qDebug() << "The rt_minutes for the middle-acquisition spectrum is:"
+               << half_tic_chrom_duration_minutes;
+
+      // Now try to actually configure the ms run reader to get that rt data.
+
+      config.setRetentionTimeStartInSeconds(
+        (half_tic_chrom_duration_minutes * 60) - 1);
+      config.setRetentionTimeEndInSeconds(
+        (half_tic_chrom_duration_minutes * 60) + 1);
+      config.setNeedPeakList(true);
+
+      spectrum_list_reader.clear();
+      ms_run_reader_sp->readSpectrumCollection2(config, spectrum_list_reader);
+
+      // How many frames are there as MS1 spectra (not MS/MS)
+      std::size_t half_tic_chrom_ms1_spectra_count =
+        spectrum_list_reader.getQualifiedMassSpectrumList().size();
+
+      qDebug() << "The number of spectra for MS level 1 is:"
+               << half_tic_chrom_ms1_spectra_count;
+
+      if(half_tic_chrom_ms1_spectra_count < 1)
+        {
+          QMessageBox::information(
+            this,
+            "Failure",
+            "There is not a single mass spectrum. Please, select a wider "
+            "retention time range for extracting the frames from the data "
+            "file.");
+
+          return false;
+        }
+
+      // Get the first spectrum in the list.
+      qualified_mass_spectrum =
+        spectrum_list_reader.getQualifiedMassSpectrumList().at(0);
+
+      std::size_t mass_spectrum_size = qualified_mass_spectrum.size();
+
+      data_exploration_results +=
+        QString("That spectrum has size %1\n").arg(mass_spectrum_size);
+
+      quint32 mz_index_begin =
+        qualified_mass_spectrum
+          .getParameterValue(
+            pappso::QualifiedMassSpectrumParameter::TimsFrameMzIndexBegin)
+          .toUInt();
+      qDebug() << "mz_index_begin:" << mz_index_begin;
+
+      quint32 mz_index_end =
+        qualified_mass_spectrum
+          .getParameterValue(
+            pappso::QualifiedMassSpectrumParameter::TimsFrameMzIndexEnd)
+          .toUInt();
+      qDebug() << "mz_index_end:" << mz_index_end;
+
+      ms_run_data_preview_info.mzBinCount = mz_index_end - mz_index_begin;
+
+      data_exploration_results +=
+        QString(
+          "The TOF indices range for that  spectrum  is "
+          "[%1-%2] = %3 total indices\n")
+          .arg(mz_index_begin)
+          .arg(mz_index_end)
+          .arg(ms_run_data_preview_info.mzBinCount);
+
+      qDebug() << "There are " << ms_run_data_preview_info.mzBinCount
+               << "TOF indices in the middle-acquisition mass spectrum";
+
+      double mz_begin =
+        qualified_mass_spectrum.getMassSpectrumCstSPtr()->at(0).x;
+      double mz_end = qualified_mass_spectrum.getMassSpectrumCstSPtr()
+                        ->at(mass_spectrum_size - 1)
+                        .x;
+
+      ms_run_data_preview_info.mzBegin = mz_begin;
+      ms_run_data_preview_info.mzEnd   = mz_end;
+
+      data_exploration_results +=
+        QString(
+          "The mass spectrum made out of all the mobility scans has m/z  range "
+          "[%1-%2] = %3  m/z range \n")
+          .arg(mz_begin)
+          .arg(mz_end)
+          .arg(mz_end - mz_begin);
+
+
+      qDebug() << "Mass spectrum spans [" << mz_begin << "-" << mz_end << "]";
+
+      qDebug() << "Rough m/z bin per TOF index: "
+               << (mz_end - mz_begin) / (mz_index_end - mz_index_begin);
+
+      data_exploration_results +=
+        QString("The digitizer thus sets one TOF index to a m/z delta of %1\n")
+          .arg((mz_end - mz_begin) / (mz_index_end - mz_index_begin));
+
+      std::size_t tims_frame_scans_count =
+        qualified_mass_spectrum
+          .getParameterValue(
+            pappso::QualifiedMassSpectrumParameter::TimsFrameScansCount)
+          .toUInt();
+
+      // This is always true, since the scans numbers are actually indices
+      ms_run_data_preview_info.ionMobilityScansBegin = 0;
+      ms_run_data_preview_info.ionMobilityScansEnd = tims_frame_scans_count - 1;
+
+      double inv_ko_range_begin =
+        qualified_mass_spectrum
+          .getParameterValue(
+            pappso::QualifiedMassSpectrumParameter::TimsFrameInvKoBegin)
+          .toDouble();
+
+      double inv_ko_range_end =
+        qualified_mass_spectrum
+          .getParameterValue(
+            pappso::QualifiedMassSpectrumParameter::TimsFrameInvKoEnd)
+          .toDouble();
+
+      ms_run_data_preview_info.ionMobilityOneOverKoBegin = inv_ko_range_begin;
+      ms_run_data_preview_info.ionMobilityOneOverKoEnd   = inv_ko_range_end;
+
+      data_exploration_results +=
+        QString(
+          "The mass spectrum has ion mobility scans in the 1/K0 range [%1-%2] "
+          "over %3 ion mobility scans\n")
+          .arg(inv_ko_range_begin)
+          .arg(inv_ko_range_end)
+          .arg(tims_frame_scans_count);
+
+      qDebug().noquote() << "The data exploration results:"
+                         << data_exploration_results
+                         << "\nNow opening the dialog.";
+
+      // As a last step, we want to know how many MS2 scans there are in the
+      // whole acquisition. We have to reninitialize the config!
+      config.reset();
+      config.setMsLevels({2});
+      config.setNeedPeakList(false);
+
+      spectrum_list_reader.clear();
+
+      ms_run_reader_sp->readSpectrumCollection2(config, spectrum_list_reader);
+      ms_run_data_preview_info.ms2SpectraCount =
+        spectrum_list_reader.getQualifiedMassSpectrumList().size();
+
+      qDebug() << "Number of MS2 spectra:"
+               << spectrum_list_reader.getQualifiedMassSpectrumList().size();
+
+      // Clear the list to free some memory.
+      spectrum_list_reader.clear();
+
+      TicChromPreviewerMassDataLoadDlg
+        *tic_chrom_previewer_mass_data_load_dlg_p =
+          new TicChromPreviewerMassDataLoadDlg(
+            this,
+            "Bruker timsTOF data loading",
+            "brukerTimsTofDataLoading",
+            "Specific data loading procedure for Bruker timsTOF data",
+            ms_run_ids.at(run_index),
+            ms_run_data_preview_info);
+
+      if(tic_chrom_previewer_mass_data_load_dlg_p->exec() != QDialog::Accepted)
+        {
+          qDebug() << "The dialog was rejected";
+          return false;
+        }
+
+      // Start with the retention time. The values from the dialog window are
+      // immediately usable.
+
+      ms_run_read_config.setRetentionTimeStartInSeconds(
+        ms_run_data_preview_info.retentionTimeBeginInSeconds);
+      ms_run_read_config.setRetentionTimeEndInSeconds(
+        ms_run_data_preview_info.retentionTimeEndInSeconds);
+
+      // The MS levels.
+      if(ms_run_data_preview_info.msLevels.size())
+        {
+          ms_run_read_config.setMsLevels(ms_run_data_preview_info.msLevels);
+          qDebug() << "The MS levels:"
+                   << ms_run_read_config.getMsLevelsAsString();
+        }
+      else
+        {
+          qDebug() << "The MS levels were not set, using the MS run reader "
+                      "config defaults:"
+                   << ms_run_read_config.getMsLevelsAsString();
+        }
+
+      qDebug() << "The number of configured MS levels:"
+               << ms_run_data_preview_info.msLevels.size();
+
+      // The ion mobility
+      if(ms_run_data_preview_info.ionMobilityUnit == IonMobilityUnit::SCAN)
+        {
+          ms_run_read_config.setParameterValue(
+            pappso::MsRunReadConfigParameter::
+              TimsFramesMsRunReader_mobility_index_begin,
+            ms_run_data_preview_info.ionMobilityScansBegin);
+          ms_run_read_config.setParameterValue(
+            pappso::MsRunReadConfigParameter::
+              TimsFramesMsRunReader_mobility_index_end,
+            ms_run_data_preview_info.ionMobilityScansEnd);
+        }
+      else if(ms_run_data_preview_info.ionMobilityUnit ==
+              IonMobilityUnit::ONE_OVER_KO)
+        {
+          ms_run_read_config.setParameterValue(
+            pappso::MsRunReadConfigParameter::
+              TimsFramesMsRunReader_mobility_one_over_k0_begin,
+            ms_run_data_preview_info.ionMobilityOneOverKoBegin);
+          ms_run_read_config.setParameterValue(
+            pappso::MsRunReadConfigParameter::
+              TimsFramesMsRunReader_mobility_one_over_k0_end,
+            ms_run_data_preview_info.ionMobilityOneOverKoEnd);
+        }
+      else
+        {
+          // There is no criterion for ion mobility, do nothing with the config.
+        }
+
+      // Finally the m/z
+      if(ms_run_data_preview_info.mzBegin > -1 &&
+         ms_run_data_preview_info.mzEnd > -1)
+        {
+          ms_run_read_config.setParameterValue(
+            pappso::MsRunReadConfigParameter::TimsFramesMsRunReader_mz_begin,
+            ms_run_data_preview_info.mzBegin);
+          ms_run_read_config.setParameterValue(
+            pappso::MsRunReadConfigParameter::TimsFramesMsRunReader_mz_end,
+            ms_run_data_preview_info.mzEnd);
+        }
+
+      if(ms_run_data_preview_info.mzBinsMergeWindow > -1)
+        {
+          ms_run_read_config.setParameterValue(
+            pappso::MsRunReadConfigParameter::
+              TimsFramesMsRunReader_mz_index_merge_window,
+            (uint)ms_run_data_preview_info.mzBinsMergeWindow);
+        }
+
+      if(ms_run_data_preview_info.flattenIonMobilityScans)
+        // Finally set the right ms run reader type, which is the one we need to
+        // take into account the MsRunReadConfig.
+        ms_file_accessor.setPreferedFileReaderType(
+          pappso::MzFormat::brukerTims, pappso::FileReaderType::tims_frames);
+      else
+        ms_file_accessor.setPreferedFileReaderType(
+          pappso::MzFormat::brukerTims, pappso::FileReaderType::tims);
     }
 
-  // Now actually load the data!
+  qDebug().noquote() << "20231021 " << ms_run_read_config.toString();
 
   // Allocate a ms run reader task to read the data.
   MsRunReadTask *ms_run_read_task_p = new MsRunReadTask(this);
@@ -287,8 +628,18 @@ ProgramWindow::openMassSpectrometryFile(const QString &file_name,
       std::const_pointer_cast<pappso::MsRunId>(ms_run_id_csp)
         ->setSampleName(sample_name);
     }
+  else
+    {
+      QFileInfo file_info(ms_file_accessor.getFileName());
+      QString base_file_name = file_info.baseName();
+      std::const_pointer_cast<pappso::MsRunId>(ms_run_id_csp)
+        ->setSampleName(base_file_name);
 
-  // qDebug() << "The run id as text:" << ms_run_id_csp->toString();
+      qDebug() << "The sample name is empty. Setting it to the file name:"
+               << base_file_name;
+    }
+
+  qDebug().noquote() << "The run id as text:" << ms_run_id_csp->toString();
 
   MassSpecDataFileLoaderSPtr loader_sp =
     std::make_shared<MassSpecDataFileLoader>(ms_file_accessor.getFileName(),
@@ -320,7 +671,6 @@ ProgramWindow::openMassSpectrometryFile(const QString &file_name,
   // that we trap to finally destroy (after a time lag of some seconds, the
   // monitor widget.
 
-
   connect(ms_run_read_task_p,
           &MsRunReadTask::finishedReadingMsRunDataSignal,
           task_monitor_composite_widget_p,
@@ -366,8 +716,10 @@ ProgramWindow::openMassSpectrometryFile(const QString &file_name,
 
   // Inform the loader that the mass spec data is there.
   loader_sp->setMsRunDataSet(ms_run_data_set_sp);
+  //
+  qRegisterMetaType<msxps::minexpert::MsRunDataSetSPtr>(
+    "msxps::minexpert::MsRunDataSetSPtr");
 
-  // qRegisterMetaType<msxps::minexpert::MsRunDataSetSPtr>("msxps::minexpert::MsRunDataSetSPtr");
   qRegisterMetaType<MsRunDataSetSPtr>("MsRunDataSetSPtr");
 
   // This is how we start the computation in the MsRunReadTask object.
@@ -409,10 +761,11 @@ ProgramWindow::openMassSpectrometryFile(const QString &file_name,
             thread_p->wait();
           });
 
-  // qDebug() << "Emitting readMsRunDataSignal(ms_run_read_task_p, "
-  //"ms_run_reader_sp, loader_sp);";
+  qDebug() << "Emitting readMsRunDataSignal(ms_run_read_task_p, "
+              "ms_run_reader_sp, loader_sp)";
 
-  emit readMsRunDataSignal(ms_run_read_task_p, ms_run_reader_sp, loader_sp);
+  emit readMsRunDataSignal(
+    ms_run_read_task_p, ms_run_reader_sp, ms_run_read_config, loader_sp);
 
   return true;
 }
@@ -1395,12 +1748,27 @@ ProgramWindow::plotCompositeWidgetDestructionRequested(
 // Here we need to finalize the reading of the ms run data set and also chain
 // with the calculation of the corresponding TIC chromatogram.
 void
-ProgramWindow::finishedReadingMsRunData(MsRunDataSetSPtr ms_run_data_set_sp)
+ProgramWindow::finishedReadingMsRunData(MsRunDataSetSPtr ms_run_data_set_sp,
+                                        double duration_seconds)
 {
 
-  // qDebug() << "Finished reading ms run data for sample name:"
-  //<< ms_run_data_set_sp->getMsRunId()->getSampleName();
+  qDebug() << "Finished reading ms run data for sample name:"
+           << ms_run_data_set_sp->getMsRunId()->getSampleName();
 
+  std::chrono::duration<long double> duration_in_seconds(duration_seconds);
+  
+  double duration_minutes = std::chrono::duration_cast<std::chrono::minutes>(duration_in_seconds).count();
+
+  QString msg = QString(
+                  "MS run data loading duration for MS run %1 "
+                  "is %2 s / %3 min")
+                  .arg(ms_run_data_set_sp->getMsRunId()->getSampleName())
+                  .arg(duration_seconds)
+                  .arg(duration_minutes);
+
+  logTextToConsole(msg);
+  
+  
   // We are here as a slot to a signal sent by the MsRunReadTask.
 
   // Increment the loaded file count so that next time we'll feed it with a new
@@ -1442,7 +1810,8 @@ ProgramWindow::finishedReadingMsRunData(MsRunDataSetSPtr ms_run_data_set_sp)
   // To debug we can ask that the ms run reader provides us with the TIC
   // chromaogram from the Bruker timsTOF data SQL database.
   
-  pappso::Trace tic_chromatogram = ms_run_data_set_sp->getMsRunReaderSPtr()->getTicChromatogram();
+  pappso::Trace tic_chromatogram = 
+ms_run_data_set_sp->getMsRunReaderSPtr()->getTicChromatogram();
   qDebug() << "Tic Chromatogram: \n" << tic_chromatogram.toString();
 #endif
 
@@ -1601,7 +1970,7 @@ void
 ProgramWindow::finishedSeedingInitialTicChromatogramAndMsRunDataSetStatistics(
   MassDataIntegrator *mass_data_integrator_p)
 {
-  // qDebug();
+  qDebug();
 
   // In this calculation, the m_mapTrace object in the integrator is the TIC
   // chroamtogram.
@@ -1638,7 +2007,7 @@ void
 ProgramWindow::finishedIntegratingQualifiedMassSpectrumVectorToTicIntensity(
   QualifiedMassSpectrumVectorMassDataIntegrator *mass_data_integrator_p)
 {
-  // qDebug();
+  //  qDebug();
 
   MsRunDataSetCstSPtr ms_run_data_set_csp =
     mass_data_integrator_p->getMsRunDataSet();
