@@ -78,8 +78,8 @@
 #include <libmassgui/includes/libmassgui/IsotopicClusterGeneratorDlg.hpp>
 #include <libmassgui/includes/libmassgui/IsotopicClusterShaperDlg.hpp>
 
-#include <libmass/MassDataServer.hpp> 
-#include <libmass/MassDataClient.hpp> 
+#include <libmass/MassDataServer.hpp>
+#include <libmass/MassDataClient.hpp>
 #include <libmassgui/includes/libmassgui/MassDataClientServerConfigDlg.hpp>
 
 
@@ -238,7 +238,7 @@ class ProgramWindow : public QMainWindow
 
   public slots:
 
-  void finishedReadingMsRunData(MsRunDataSetSPtr ms_run_data_set_sp);
+  void finishedReadingMsRunData(MsRunDataSetSPtr ms_run_data_set_sp, double duration_seconds);
 
   void finishedSeedingInitialTicChromatogramAndMsRunDataSetStatistics(
     MassDataIntegrator *mass_data_integrator_p);
@@ -265,6 +265,7 @@ class ProgramWindow : public QMainWindow
 
   void readMsRunDataSignal(MsRunReadTask *ms_run_read_task_p,
                            pappso::MsRunReaderSPtr ms_run_reader_sp,
+                           const pappso::MsRunReadConfig &ms_run_reader_config,
                            std::shared_ptr<MassSpecDataFileLoader> loader_sp);
 
   void seedInitialTicChromatogramAndMsRunDataSetStatisticsSignal(
@@ -340,7 +341,8 @@ class ProgramWindow : public QMainWindow
 
   ConsoleWnd *mp_consoleWnd = nullptr;
 
-  libmassgui::IsotopicClusterGeneratorDlg *mp_isotopicClusterGeneratorDlg               = nullptr;
+  libmassgui::IsotopicClusterGeneratorDlg *mp_isotopicClusterGeneratorDlg =
+    nullptr;
   libmassgui::IsotopicClusterShaperDlg *mp_isotopicClusterShaperDlg = nullptr;
 
   libmassgui::MassDataClientServerConfigDlg *mp_clientServerConfigDlg = nullptr;
@@ -351,7 +353,6 @@ class ProgramWindow : public QMainWindow
 
   AboutDlg *mp_aboutDlg = nullptr;
 
-
   AnalysisPreferences *mpa_analysisPreferences = nullptr;
 
   libmass::MassDataClient *mpa_massDataClient = nullptr;
@@ -424,7 +425,9 @@ class ProgramWindow : public QMainWindow
 
   bool startServer();
   void stopServer();
-  bool startClient(const QString &ip_address, int port_number, int connection_frequency = 1);
+  bool startClient(const QString &ip_address,
+                   int port_number,
+                   int connection_frequency = 1);
   void stopClient();
 
   void dispatchReceivedData(const QByteArray &byte_array);
