@@ -282,7 +282,7 @@ TicXicChromMassSpecColorMapPlotCompositeWidget::integrationRequested(
   // Now we need to add a new step in that processing flow so that we document
   // this new integration that we are performing.
 
-  ProcessingStep *processing_step_p = new ProcessingStep();
+  ProcessingStepSPtr processing_step_sp = std::make_shared<ProcessingStep>();
 
   // If the user had set ms fragmentation specifications, all these are listed
   // in the various ProcessingSpec instances, so we do not loose any. However,
@@ -301,7 +301,7 @@ TicXicChromMassSpecColorMapPlotCompositeWidget::integrationRequested(
       // flow " "is valid, using it:"
       //<< ms_fragmentation_spec.toString();
 
-      processing_step_p->setMsFragmentationSpec(ms_fragmentation_spec);
+      processing_step_sp->setMsFragmentationSpec(ms_fragmentation_spec);
     }
   else
     {
@@ -363,17 +363,17 @@ TicXicChromMassSpecColorMapPlotCompositeWidget::integrationRequested(
 
   // Now we know we have the right selection polygon for x:MZ and y:RT.
 
-  processing_step_p->setDataKind(pappso::Axis::x, pappso::DataKind::mz);
-  processing_step_p->setDataKind(pappso::Axis::y, pappso::DataKind::rt);
+  processing_step_sp->setDataKind(pappso::Axis::x, pappso::DataKind::mz);
+  processing_step_sp->setDataKind(pappso::Axis::y, pappso::DataKind::rt);
 
 
   // And now actually set the selection polygon to the step.
 
-  processing_step_p->setSelectionPolygon(local_selection_polygon);
+  processing_step_sp->setSelectionPolygon(local_selection_polygon);
 
   // We must say what is the data source processing type.
-  processing_step_p->setSrcProcessingType(pappso::Axis::x, "MZ");
-  processing_step_p->setSrcProcessingType(pappso::Axis::y, "RT");
+  processing_step_sp->setSrcProcessingType(pappso::Axis::x, "MZ");
+  processing_step_sp->setSrcProcessingType(pappso::Axis::y, "RT");
 
   // Now we need to document not the source but the destination. What kind of
   // integration are we about to perform?
@@ -382,9 +382,10 @@ TicXicChromMassSpecColorMapPlotCompositeWidget::integrationRequested(
     {
       // qDebug() << "Integrating to XIC chromatogram.";
 
-      processing_step_p->setDestProcessingType("RT");
+      processing_step_sp->setDestProcessingType("RT");
 
-      local_processing_flow.push_back(processing_step_p);
+      // Should perform automatically the conversion from non-const to const.
+      local_processing_flow.push_back(processing_step_sp);
 
       static_cast<BaseColorMapPlotWnd *>(mp_parentWnd)
         ->integrateToRt(plottable_p, local_processing_flow);
@@ -393,9 +394,10 @@ TicXicChromMassSpecColorMapPlotCompositeWidget::integrationRequested(
     {
       // qDebug() << "Integrating to dt / rt color map.";
 
-      processing_step_p->setDestProcessingType("DT_RT");
+      processing_step_sp->setDestProcessingType("DT_RT");
 
-      local_processing_flow.push_back(processing_step_p);
+      // Should perform automatically the conversion from non-const to const.
+      local_processing_flow.push_back(processing_step_sp);
 
       static_cast<BaseColorMapPlotWnd *>(mp_parentWnd)
         ->integrateToDtRt(plottable_p, local_processing_flow);
@@ -409,19 +411,19 @@ TicXicChromMassSpecColorMapPlotCompositeWidget::integrationRequested(
         {
           // qDebug() << "Integrating to mass spectrum.";
 
-          processing_step_p->setDestProcessingType("MZ");
+          processing_step_sp->setDestProcessingType("MZ");
         }
       else if(m_ui.integrateToMzRtPushButton->isChecked())
         {
           // qDebug() << "Integrating to m/z / rt color map.";
 
-          processing_step_p->setDestProcessingType("MZ_RT");
+          processing_step_sp->setDestProcessingType("MZ_RT");
         }
       else if(m_ui.integrateToDtMzPushButton->isChecked())
         {
           // qDebug() << "Integrating to dt / m/z color map.";
 
-          processing_step_p->setDestProcessingType("DT_MZ");
+          processing_step_sp->setDestProcessingType("DT_MZ");
         }
 
       // At this point we need to define how the mass data integrator will
@@ -457,17 +459,17 @@ TicXicChromMassSpecColorMapPlotCompositeWidget::integrationRequested(
       // while it was loaded from file.
       if(!mz_integration_params.isValid())
         {
-          //qDebug() << "The most recent mz integ param are not valid. We use "
-                      //"the getMsRunDataSetStats to craft new ones that we may "
-                      //"tune later.";
+          // qDebug() << "The most recent mz integ param are not valid. We use "
+          //"the getMsRunDataSetStats to craft new ones that we may "
+          //"tune later.";
 
           mz_integration_params =
             ms_run_data_set_csp->craftInitialMzIntegrationParams();
         }
       else
         {
-          //qDebug() << "The most recent mz integ params are valid. Use them, "
-                      //"with potential tuning.";
+          // qDebug() << "The most recent mz integ params are valid. Use them, "
+          //"with potential tuning.";
         }
 
       if(!mz_integration_params.isValid())
@@ -500,8 +502,8 @@ TicXicChromMassSpecColorMapPlotCompositeWidget::integrationRequested(
       mz_integration_params.setSmallestMz(mz_range_lower);
       mz_integration_params.setGreatestMz(mz_range_upper);
 
-      //qDebug() << "After tuning the mz range, mz integration params:"
-               //<< mz_integration_params.toString();
+      // qDebug() << "After tuning the mz range, mz integration params:"
+      //<< mz_integration_params.toString();
 
 
 #if 0
@@ -524,12 +526,14 @@ TicXicChromMassSpecColorMapPlotCompositeWidget::integrationRequested(
 
       // We finally have mz integ params that we can set to the processing step
       // that we are creating to document this current integration.
-      processing_step_p->setMzIntegrationParams(mz_integration_params);
+      processing_step_sp->setMzIntegrationParams(mz_integration_params);
 
       // And nwo add the new processing step to the local copy of the processing
       // flow, so that we document on top of all the previous steps, also this
       // last one.
-      local_processing_flow.push_back(processing_step_p);
+
+      // Should perform automatically the conversion from non-const to const.
+      local_processing_flow.push_back(processing_step_sp);
 
       // qDebug().noquote() << "Pushed back new processing step:"
       //<< processing_step_p->toString();
@@ -555,22 +559,24 @@ TicXicChromMassSpecColorMapPlotCompositeWidget::integrationRequested(
     }
   else if(m_ui.integrateToDtPushButton->isChecked())
     {
-      //qDebug() << "Integrating to drift spectrum.";
+      // qDebug() << "Integrating to drift spectrum.";
 
-      processing_step_p->setDestProcessingType("DT");
+      processing_step_sp->setDestProcessingType("DT");
 
-      local_processing_flow.push_back(processing_step_p);
+      // Should perform automatically the conversion from non-const to const.
+      local_processing_flow.push_back(processing_step_sp);
 
       static_cast<BaseColorMapPlotWnd *>(mp_parentWnd)
         ->integrateToDt(plottable_p, local_processing_flow);
     }
   else if(m_ui.integrateToIntPushButton->isChecked())
     {
-      //qDebug() << "Integrating to TIC intensity.";
+      // qDebug() << "Integrating to TIC intensity.";
 
-      processing_step_p->setDestProcessingType("INT");
+      processing_step_sp->setDestProcessingType("INT");
 
-      local_processing_flow.push_back(processing_step_p);
+      // Should perform automatically the conversion from non-const to const.
+      local_processing_flow.push_back(processing_step_sp);
 
       static_cast<BasePlotWnd *>(mp_parentWnd)
         ->integrateToTicIntensity(plottable_p, nullptr, local_processing_flow);
