@@ -334,7 +334,7 @@ TicXicChromTracePlotCompositeWidget::integrationRequested(
 
   // Create a processing step to document the specifics of this new integration.
 
-  ProcessingStep *processing_step_p = new ProcessingStep();
+  ProcessingStepSPtr processing_step_sp = std::make_shared<ProcessingStep>();
 
   // If the user had set ms fragmentation specifications, all these are listed
   // in the various ProcessingSpec instances, so we do not loose any. However,
@@ -353,7 +353,7 @@ TicXicChromTracePlotCompositeWidget::integrationRequested(
       // flow " "is valid, using it:"
       //<< ms_fragmentation_spec.toString();
 
-      processing_step_p->setMsFragmentationSpec(ms_fragmentation_spec);
+      processing_step_sp->setMsFragmentationSpec(ms_fragmentation_spec);
     }
   else
     {
@@ -367,17 +367,17 @@ TicXicChromTracePlotCompositeWidget::integrationRequested(
 
   // qDebug();
 
-  processing_step_p->setSelectionPolygon(local_context.m_selectionPolygon);
+  processing_step_sp->setSelectionPolygon(local_context.m_selectionPolygon);
 
   // qDebug();
 
   // We must say what is the data source processing type.
-  processing_step_p->setSrcProcessingType(pappso::Axis::x, "RT");
+  processing_step_sp->setSrcProcessingType(pappso::Axis::x, "RT");
 
   // It is essential that we document the relation between the axes and the
   // corresponding data type.
-  processing_step_p->setDataKind(pappso::Axis::x, pappso::DataKind::rt);
-  processing_step_p->setDataKind(pappso::Axis::y, pappso::DataKind::unset);
+  processing_step_sp->setDataKind(pappso::Axis::x, pappso::DataKind::rt);
+  processing_step_sp->setDataKind(pappso::Axis::y, pappso::DataKind::unset);
 
   // Now handle the specific part of the ProcessingStep, that part that depends
   // on the kind of integration the user is willing to perform. Note below that
@@ -389,9 +389,9 @@ TicXicChromTracePlotCompositeWidget::integrationRequested(
     {
       // qDebug() << "Integration to XIC chromatogram.";
 
-      processing_step_p->setDestProcessingType("RT");
+      processing_step_sp->setDestProcessingType("RT");
 
-      local_processing_flow.push_back(processing_step_p);
+      local_processing_flow.push_back(processing_step_sp);
 
       static_cast<TicXicChromTracePlotWnd *>(mp_parentWnd)
         ->integrateToRt(plottable_p, nullptr, local_processing_flow);
@@ -403,7 +403,7 @@ TicXicChromTracePlotCompositeWidget::integrationRequested(
       if(m_ui.integrateToMzPushButton->isChecked())
         {
           // qDebug() << "Integrating to mass spectrum.";
-          processing_step_p->setDestProcessingType("MZ");
+          processing_step_sp->setDestProcessingType("MZ");
 
           // qDebug() << "Currently elaborating processing_step_p: "
           //<< processing_step_p->toString();
@@ -411,12 +411,12 @@ TicXicChromTracePlotCompositeWidget::integrationRequested(
       else if(m_ui.integrateToMzRtPushButton->isChecked())
         {
           // qDebug() << "Integrating to rt|m/z color map.";
-          processing_step_p->setDestProcessingType("MZ_RT");
+          processing_step_sp->setDestProcessingType("MZ_RT");
         }
       else if(m_ui.integrateToDtMzPushButton->isChecked())
         {
           // qDebug() << "Integrating to dt|m/z color map.";
-          processing_step_p->setDestProcessingType("DT_MZ");
+          processing_step_sp->setDestProcessingType("DT_MZ");
         }
 
       // At this point we need to define how the mass data integrator will
@@ -470,12 +470,14 @@ TicXicChromTracePlotCompositeWidget::integrationRequested(
 
       // We finally have mz integ params that we can set to the processing step
       // that we are creating to document this current integration.
-      processing_step_p->setMzIntegrationParams(mz_integration_params);
+      processing_step_sp->setMzIntegrationParams(mz_integration_params);
 
       // And nwo add the new processing step to the local copy of the processing
       // flow, so that we document on top of all the previous steps, also this
       // last one.
-      local_processing_flow.push_back(processing_step_p);
+
+      // Should perform automatically the conversion from non-const to const.
+      local_processing_flow.push_back(processing_step_sp);
 
       // qDebug();
 
@@ -502,9 +504,10 @@ TicXicChromTracePlotCompositeWidget::integrationRequested(
     {
       // qDebug() << "Integrating to drift spectrum.";
 
-      processing_step_p->setDestProcessingType("DT");
+      processing_step_sp->setDestProcessingType("DT");
 
-      local_processing_flow.push_back(processing_step_p);
+      // Should perform automatically the conversion from non-const to const.
+      local_processing_flow.push_back(processing_step_sp);
 
       static_cast<TicXicChromTracePlotWnd *>(mp_parentWnd)
         ->integrateToDt(plottable_p, local_processing_flow);
@@ -513,9 +516,10 @@ TicXicChromTracePlotCompositeWidget::integrationRequested(
     {
       // qDebug() << "Integrating to dt/rt colormap.";
 
-      processing_step_p->setDestProcessingType("DT_RT");
+      processing_step_sp->setDestProcessingType("DT_RT");
 
-      local_processing_flow.push_back(processing_step_p);
+      // Should perform automatically the conversion from non-const to const.
+      local_processing_flow.push_back(processing_step_sp);
 
       static_cast<TicXicChromTracePlotWnd *>(mp_parentWnd)
         ->integrateToDtRt(plottable_p, local_processing_flow);
@@ -524,9 +528,10 @@ TicXicChromTracePlotCompositeWidget::integrationRequested(
     {
       // qDebug() << "Integrating to TIC intensity.";
 
-      processing_step_p->setDestProcessingType("INT");
+      processing_step_sp->setDestProcessingType("INT");
 
-      local_processing_flow.push_back(processing_step_p);
+      // Should perform automatically the conversion from non-const to const.
+      local_processing_flow.push_back(processing_step_sp);
 
       static_cast<BasePlotWnd *>(mp_parentWnd)
         ->integrateToTicIntensity(plottable_p, nullptr, local_processing_flow);
