@@ -185,19 +185,33 @@ TicXicChromTracePlotWnd::finishedIntegratingToInitialTicChromatogram(
   // thus replace that MS level to 0, that means that all the data (whatever the
   // MS level) will be handled from there.
 
-  const ProcessingStep *most_recent_step_p = processing_flow.mostRecentStep();
+  // ProcessingStepCstSPtr most_recent_step_csp =
+  // processing_flow.mostRecentStep();
 
-  if(most_recent_step_p->destMatches("FILE_RT"))
-    qFatal(
-      "Cannot be that there are either no or more than one processing step for "
-      "type FILE_RT");
+  ProcessingStepSPtr most_recent_step_sp =
+    std::const_pointer_cast<ProcessingStep>(processing_flow.mostRecentStep());
+
+  // Logically, this should be the very first step in the processing flow, since
+  // this is the very first processing step that is performed when opening a
+  // data file.
+
+  if(most_recent_step_sp != nullptr)
+    qDebug() << "Odd situation that a processing step existed before now.";
+
+  // if(most_recent_step_sp->destMatches("FILE_RT"))
+  //   qFatal(
+  //     "Cannot be that there are either no or more than one processing step
+  //     for " "type FILE_RT");
 
   // We need to const_cast the step in order to overwrite is
   // MsFragmentationSpec.
   MsFragmentationSpec *fragmentation_spec_p =
-    const_cast<ProcessingStep *>(most_recent_step_p)
-      ->getMsFragmentationSpecPtr();
+    most_recent_step_sp->getMsFragmentationSpecPtr();
 
+  /*     MsFragmentationSpec *fragmentation_spec_p =
+       const_pointer_cast<ProcessingStepSPtr>(most_recent_step_sp)
+       ->getMsFragmentationSpecPtr();
+  */
   // While we had set the MS level to 1 because when computing a TIC
   // chromatogram we only do that with MS1 data, we now want to set it to 0
   // because all the later integrations need to be capable of involving any
